==> igniteui-react-charts-16.6.4.tgz: package/ES5/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, enumGetBox, markType } from "igniteui-react-core/ES5/type";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES5/Path";
var PolarLineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bf = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.o4 = a;
    };
    PolarLineSeries.prototype.o2 = function (a) {
        var b = a;
        b.c0();
    };
    PolarLineSeries.prototype.o3 = function (a, b) {
        var c = b;
        c.c1(a.m, this.eq);
    };
    PolarLineSeries.prototype.ou = function () {
        return this.o5;
    };
    PolarLineSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.i4(false);
                this.ib();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
Type.dep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:o5:o7', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
var PolarLineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.cz = null;
        _this.c2 = new Path();
        _this.cz = a;
        return _this;
    }
    PolarLineSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
    };
    PolarLineSeriesView.prototype.c0 = function () {
        this.c2.aj = null;
        this.an();
    };
    PolarLineSeriesView.prototype.c1 = function (a, b) {
        this.cz.or.d(this.c2, a, b);
        this.an();
    };
    PolarLineSeriesView.prototype.a8 = function () {
        _super.prototype.a8.call(this);
        this.c2._stroke = this.e.ku;
        this.c2.ac = this.e.eu;
        this.c2.ai = this.e.k2;
        this.c2.ad = this.e.k3;
    };
    PolarLineSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        var a = this.bl();
        this.c2._stroke = a;
        this.c2.ac = this.e.eu + 3;
    };
    PolarLineSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        a.s(this.c2);
    };
    PolarLineSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.c2, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, enumGetBox, markType } from "igniteui-react-core/ES5/type";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES5/Path";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bf = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.im = function (a) {
        _super.prototype.im.call(this, a);
        this.o6 = a;
    };
    PolarLineSeries.prototype.o4 = function (a) {
        var b = a;
        b.c0();
    };
    PolarLineSeries.prototype.o5 = function (a, b) {
        var c = b;
        c.c1(a.m, this.er);
    };
    PolarLineSeries.prototype.ow = function () {
        return this.o7;
    };
    PolarLineSeries.prototype.is = function (a, b, c, d) {
        _super.prototype.is.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.i6(false);
                this.ic();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
Type.dep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:o7:o9', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.cz = null;
        _this.c2 = new Path();
        _this.cz = a;
        return _this;
    }
    PolarLineSeriesView.prototype.ap = function () {
        _super.prototype.ap.call(this);
    };
    PolarLineSeriesView.prototype.c0 = function () {
        this.c2.aj = null;
        this.an();
    };
    PolarLineSeriesView.prototype.c1 = function (a, b) {
        this.cz.ot.d(this.c2, a, b);
        this.an();
    };
    PolarLineSeriesView.prototype.a8 = function () {
        _super.prototype.a8.call(this);
        this.c2._stroke = this.e.kw;
        this.c2.ac = this.e.ev;
        this.c2.ai = this.e.k4;
        this.c2.ad = this.e.k5;
    };
    PolarLineSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        var a = this.bl();
        this.c2._stroke = a;
        this.c2.ac = this.e.ev + 3;
    };
    PolarLineSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        a.s(this.c2);
    };
    PolarLineSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.c2, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };
